pub struct DdSketch {
pub mapping: Option<IndexMapping>,
pub positive_values: Option<Store>,
pub negative_values: Option<Store>,
pub zero_count: f64,
}Expand description
A DDSketch is essentially a histogram that partitions the range of positive values into an infinite number of indexed bins whose size grows exponentially. It keeps track of the number of values (or possibly floating-point weights) added to each bin. Negative values are partitioned like positive values, symmetrically to zero. The value zero as well as its close neighborhood that would be mapped to extreme bin indexes is mapped to a specific counter.
Fields
mapping: Option<IndexMapping>The mapping between positive values and the bin indexes they belong to.
positive_values: Option<Store>The store for keeping track of positive values.
negative_values: Option<Store>The store for keeping track of negative values. A negative value v is mapped using its positive opposite -v.
zero_count: f64The count for the value zero and its close neighborhood (whose width depends on the mapping).