Store

Struct Store 

pub struct Store {
    pub bin_counts: HashMap<i32, f64>,
    pub contiguous_bin_counts: Vec<f64>,
    pub contiguous_bin_index_offset: i32,
}
A Store maps bin indexes to their respective counts. Counts can be encoded sparsely using binCounts, but also in a contiguous way using contiguousBinCounts and contiguousBinIndexOffset. Given that non-empty bins are in practice usually contiguous or close to one another, the latter contiguous encoding method is usually more efficient than the sparse one. Both encoding methods can be used conjointly. If a bin appears in both the sparse and the contiguous encodings, its count value is the sum of the counts in each encodings.

Fields

bin_counts: HashMap<i32, f64>

The bin counts, encoded sparsely.

contiguous_bin_counts: Vec<f64>

The bin counts, encoded contiguously. The values of contiguousBinCounts are the counts for the bins of indexes o, o+1, o+2, etc., where o is contiguousBinIndexOffset.

contiguous_bin_index_offset: i32